package com.bwie.gateway.filters;


import com.bwie.common.constants.TokenConstants;
import com.bwie.common.utils.JwtUtils;
import com.bwie.common.utils.StringUtils;
import com.bwie.gateway.config.IgnoreWhiteConfig;
import com.bwie.gateway.utils.GatewayUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.gateway.filter.GatewayFilterChain;
import org.springframework.cloud.gateway.filter.GlobalFilter;
import org.springframework.core.Ordered;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.http.server.reactive.ServerHttpRequest;
import org.springframework.stereotype.Component;
import org.springframework.web.server.ServerWebExchange;
import reactor.core.publisher.Mono;

import java.util.List;

@Component
public class GateWayFilters implements GlobalFilter, Ordered {
    @Autowired
    private StringRedisTemplate stringRedisTemplate;
    @Autowired
    private IgnoreWhiteConfig ignoreWhiteConfig;
    @Override
    public Mono<Void> filter(ServerWebExchange exchange, GatewayFilterChain chain) {
        List<String> whites = ignoreWhiteConfig.getWhites();
        ServerHttpRequest request = exchange.getRequest();
        String path = request.getURI().getPath();
        if(StringUtils.matches(path,whites)){
            return chain.filter(exchange);
        }

        String token = request.getHeaders().getFirst("token");
        if(token==null){
            return GatewayUtils.errorResponse(exchange,"token值不能为空");
        }


        try {
            JwtUtils.parseToken(token);
        } catch (Exception e) {
          return GatewayUtils.errorResponse(exchange,"token不合法");
        }

        String userKey = JwtUtils.getUserKey(token);


        if(!stringRedisTemplate.hasKey(TokenConstants.LOGIN_TOKEN_KEY+userKey)){

            return GatewayUtils.errorResponse(exchange,"token已经过期请重新获取");
        }
        return chain.filter(exchange);

    }

    @Override
    public int getOrder() {
        return 0;
    }
}
