package com.bwie.controller;

import com.bwie.Feign.GoodsFeign;
import com.bwie.common.domain.Room;
import com.bwie.common.domain.User;
import com.bwie.common.domain.request.RoomRentReq;
import com.bwie.common.domain.request.RoomReq;
import com.bwie.common.result.PageResult;
import com.bwie.common.result.Result;
import com.bwie.service.GoodsService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/goods")
public class GoodsController {
    @Autowired
    private GoodsService goodsService;

    @Autowired
    private GoodsFeign goodsFeign;
    //获取房屋列表
    @PostMapping("/findRoomList")
    public Result<PageResult<Room>> findRoomList(@RequestBody RoomReq roomReq){
        PageHelper.startPage(roomReq.getPageNum(),roomReq.getPageSize());
        List<Room> roomList=goodsService.findRoomList(roomReq);
        PageInfo<Room> roomPageInfo = new PageInfo<>(roomList);
        return PageResult.toResult(roomPageInfo.getTotal(),roomPageInfo.getList());
    }

    //添加租房贷款审批记录表
    @PostMapping("/addRecord")
    public Result addRecord(@RequestBody RoomRentReq roomRentReq){
      return    goodsService.addRecord(roomRentReq);
    }

    //租房判断此用户是否已经租房，如果已经存在租房记录，并且未到期，则不可以再次进行租房

    @GetMapping("/ment")
    public Result ment(){
        return goodsService.ment();
    }

    // 使用定时任务每30秒自动审批用户贷款申请（5分）
    @Scheduled(cron = "30 * * * * ?")
    public void  judgment(){
        List<Integer> userIds=goodsService.findUserIds();
        for (Integer userId : userIds) {
            User user=goodsService.findUserById(userId);
            //审核
           Integer i = goodsService.update(user);
           if(i>0){
               goodsFeign.send(user);
           }
        }
    }
}
