package com.bwie.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.Room;
import com.bwie.common.domain.User;
import com.bwie.common.domain.request.RoomRentReq;
import com.bwie.common.domain.request.RoomReq;
import com.bwie.common.domain.response.RecordRep;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.mapper.GoodsMapper;
import com.bwie.service.GoodsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

@Service
public class GoodsServiceImpl implements GoodsService {
    @Autowired
    private GoodsMapper goodsMapper;
    @Autowired
    private HttpServletRequest request;
    @Autowired
    private StringRedisTemplate stringRedisTemplate;

    @Override
    public List<Room> findRoomList(RoomReq roomReq) {
        return goodsMapper.findRoomList(roomReq);
    }

    @Override
    public Result addRecord(RoomRentReq roomRentReq) {
        //判断是否已经存在存在租房记录
        String token = request.getHeader("token");
        String userKey = JwtUtils.getUserKey(token);
        String s = stringRedisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        User user = JSONObject.parseObject(s, User.class);

        roomRentReq.setUserId(user.getUserId());
       RecordRep recordRep = goodsMapper.findRecordByUserId(user.getUserId());

       //没有优惠的添加租房贷款审批记录
       if(recordRep!=null){
           Integer i = goodsMapper.add(roomRentReq);
           return Result.error("你已经为二次租房用户不在享受优惠,一下订单如有异议请联系客服取消");
       }else{
           //有优惠的添加租房贷款审批记录
           Integer i = goodsMapper.addDisPrice(roomRentReq);
           return Result.success();
       }


    }

    @Override
    public Result ment() {
        //判断是否已经存在存在租房记录
        String token = request.getHeader("token");
        String userKey = JwtUtils.getUserKey(token);
        String s = stringRedisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        User user = JSONObject.parseObject(s, User.class);

        RecordRep recordRep = goodsMapper.findRecord(user.getUserId());

        if(recordRep==null){
            return Result.success();
        }else{
            return Result.error("你租房还没有到期不能重复租房");
        }


    }

    @Override
    public List<Integer> findUserIds() {
        return goodsMapper.findUserIds();
    }

    @Override
    public User findUserById(Integer userId) {
        return goodsMapper.findUSerById(userId);
    }

    @Override
    public Integer update(User user) {

        return   goodsMapper.update(user);


    }
}
